=================
API Documentation
=================

Skos module
-----------

.. automodule:: skosprovider.skos
   :members:

Providers module
----------------

.. automodule:: skosprovider.providers
   :members: VocabularyProvider, MemoryProvider, DictionaryProvider, SimpleCsvProvider
   :special-members: __init__

Registry module
---------------

.. automodule:: skosprovider.registry
   :members:

Uri module
----------

.. automodule:: skosprovider.uri
   :members:

JsonLd module
-------------

.. automodule:: skosprovider.jsonld
   :members:

Exceptions module
-----------------

.. automodule:: skosprovider.exceptions
   :members:

Utils module
---------------

.. automodule:: skosprovider.utils
   :members:
